

<p align="center">
    <a href="https://sprout.seedcase-project.org/">
        <img src="https://raw.githubusercontent.com/seedcase-project/seedcase-sprout/main/_extensions/seedcase-project/seedcase-theme/logos/navbar-logo-seedcase-sprout.svg" alt="Link to Sprout website" height="150"/>
    </a>
</p>

## seedcase-sprout: Grow structured, organised, and FAIR data

[![Copier](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/copier-org/copier/master/img/badge/badge-grayscale-inverted-border-teal.json?raw=true.svg)](https://github.com/copier-org/copier)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.15800477.svg)](https://doi.org/10.5281/zenodo.15800477)
[![GitHub
License](https://img.shields.io/github/license/seedcase-project/seedcase-sprout.svg)](https://github.com/seedcase-project/seedcase-sprout/blob/main/LICENSE.md)
[![PyPI
Version](https://img.shields.io/pypi/v/seedcase-sprout.svg)](https://pypi.org/project/seedcase-sprout/)
[![GitHub
Release](https://img.shields.io/github/v/release/seedcase-project/seedcase-sprout.svg)](https://github.com/seedcase-project/seedcase-sprout/releases/latest)
[![Supported Python Version from PEP 621
TOML](https://img.shields.io/python/required-version-toml?tomlFilePath=https://raw.githubusercontent.com/seedcase-project/seedcase-sprout/refs/heads/main/pyproject.toml)](https://github.com/seedcase-project/seedcase-sprout/blob/main/pyproject.toml)
[![OpenSSF
Scorecard](https://api.scorecard.dev/projects/github.com/seedcase-project/seedcase-sprout/badge?raw=true.svg)](https://scorecard.dev/viewer/?uri=github.com/seedcase-project/seedcase-sprout)
[![Build
package](https://github.com/seedcase-project/seedcase-sprout/actions/workflows/build-package.yml/badge.svg)](https://github.com/seedcase-project/seedcase-sprout/actions/workflows/build-package.yml)
[![Build
documentation](https://github.com/seedcase-project/seedcase-sprout/actions/workflows/build-website.yml/badge.svg)](https://github.com/seedcase-project/seedcase-sprout/actions/workflows/build-website.yml)
[![CodeQL](https://github.com/seedcase-project/seedcase-sprout/actions/workflows/github-code-scanning/codeql/badge.svg?branch=main)](https://github.com/seedcase-project/seedcase-sprout/actions/workflows/github-code-scanning/codeql)
[![pre-commit.ci
status](https://results.pre-commit.ci/badge/github/seedcase-project/seedcase-sprout/main.svg)](https://results.pre-commit.ci/latest/github/seedcase-project/seedcase-sprout/main)
[![code
coverage](https://raw.githubusercontent.com/seedcase-project/seedcase-sprout/coverage/coverage.svg?raw=true)](https://htmlpreview.github.io/?https://raw.githubusercontent.com/seedcase-project/seedcase-sprout/coverage/index.html)
[![lifecycle](https://lifecycle.r-lib.org/articles/figures/lifecycle-experimental.svg)](https://lifecycle.r-lib.org/articles/stages.html#experimental)
[![Project Status: Active – The project has reached a stable, usable
state and is being actively
developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)
[![OpenSSF Best
Practices](https://www.bestpractices.dev/projects/10459/badge?raw=true.svg)](https://www.bestpractices.dev/projects/10459)

Sprout is one component of the [Seedcase
Project](https://seedcase-project.org) framework that aims to take data
created or collected for research studies and “grow” it in a structured
way using modern data engineering best practices. Sprout is designed to
organise, describe, and store data for effective discovery, management,
and analysis.

Check out our [website](https://sprout.seedcase-project.org/) for more
information, such as an
[overview](https://sprout.seedcase-project.org/docs/overview/), how to
use it [guide](https://sprout.seedcase-project.org/docs/guide/), or to
read about the
[design](https://sprout.seedcase-project.org/docs/design/). For a list
of changes, see our
[changelog](https://sprout.seedcase-project.org/docs/releases/) page.

## Installing

Seedcase Sprout can be installed in two ways. The first is to install it
as a user, and the second is to install it as a contributor.

To install Sprout for general use, see our [Installation
Guide](https://sprout.seedcase-project.org/docs/guide/installation).

## Contributing

Check out our [contributing document](CONTRIBUTING.md) for information
on how to contribute to the project, including how to set up your
development environment.

Please note that this project is released with a [Contributor Code of
Conduct](CODE_OF_CONDUCT.md). By participating in this project you agree
to abide by its terms.

## Licensing

This project is licensed under the [MIT License](LICENSE.md).

## Changelog

For a list of changes, see our [changelog](CHANGELOG.md) page.

## Citing

This project is part of the Seedcase Project, which is a collaborative
effort to create a framework for data management and analysis in
research. If you use this project in your work, please cite it as
follows:

Johnston L.W., Brødbæk S.K., Beicher K., Vago M. Seedcase Sprout: Grow
structured, organised, and FAIR data. DOI: 10.5281/zenodo.15800477 URL:
https://sprout.seedcase-project.org

Or as a BibTeX entry:

    @misc{YourReferenceHere,
    author = {Johnston, Luke William and Brødbæk, Signe Kirk and Beicher, Kristiane and Vago, Marton},
    doi = {10.5281/zenodo.15800477},
    title = {Seedcase Sprout: Grow structured, organised, and FAIR data.},
    url = {https://sprout.seedcase-project.org}
    }
